==> turbina-2.05.tgz: turbina-2.05/src/access.cpp <==
#include <unistd.h>
#include <pwd.h>
#include <grp.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <stdlib.h>
#include "access.h"
#include "names.h"
// To prevent problems with missing built-in strcmp():
#include <string.h>

#include <stdio.h>

gid_t getGID( const char* grName) {
	struct group* gr = getgrnam( grName );
	if(!gr) {
		printf("No %s group\n",grName);
		exit(1);
	}
	return gr->gr_gid;
}

bool getMassAccess( void ) {
// user:
	uid_t uid = getuid();
//	printf( "uid=%d\n",uid );
	if( uid == ROOT_UID ) {
//		printf( "It's Root!\n" );
		return true;	// system root
	}
	struct passwd* pw = getpwuid( uid );
	char* userName = pw->pw_name;

// massRoot-group:
	setgrent(); // to begin
//	struct group* gr = getgrgid( MASS_ROOT_GID);
	struct group* gr = getgrnam( massRootGroupName );
//	printf( "gr_name=%s gr_gid=%d\n",
//		gr->gr_name, gr->gr_gid );

	int i = 0;
	char** mem = gr->gr_mem;
	while( mem[i] ) {
//		printf( "%s ?\n",mem[i] );
		if( strcmp( mem[i], userName ) == 0 ) {
//			printf( "%s is MassRoot!\n",userName );
			return true;
		}
		i++;
	}
//	printf( "%s is User!\n",userName );
	return false;
}

void setAccess( const char* fileName, bool toMassRoot ) {
	if(!fileName) return;
	gid_t gid;
//	if( toMassRoot ) gid = (gid_t)MASS_ROOT_GID;
//	else gid = (gid_t)MASS_GID;
	if( toMassRoot ) gid = getGID( massRootGroupName );
	else gid = getGID( massUserGroupName );

	chown( fileName, (uid_t) -1, gid );
	chmod( fileName, S_IRUSR | S_IWUSR |
			S_IRGRP | S_IWGRP | S_IROTH );
}

/*
int main( int argc, char ** argv ) {
	getMassAccess();
}
*/

==> turbina-2.056.tgz: turbina-2.056/src/access.cpp <==
#include <unistd.h>
#include <pwd.h>
#include <grp.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <stdlib.h>
#include "access.h"
#include "names.h"
// To prevent problems with missing built-in strcmp():
#include <string.h>

#include <stdio.h>

gid_t getGID( const char* grName) {
	struct group* gr = getgrnam( grName );
	if(!gr) {
		printf("No %s group\n",grName);
		exit(1);
	}
	return gr->gr_gid;
}

bool getMassAccess( void ) {
// user:
	uid_t uid = geteuid();
//	printf( "uid=%d\n",uid );
	if( uid == ROOT_UID ) {
//		printf( "It's Root!\n" );
		return true;	// system root
	}
	struct passwd* pw = getpwuid( uid );
	char* userName = pw->pw_name;
	setenv("HOME",pw->pw_dir,1);

// massRoot-group:
	setgrent(); // to begin
//	struct group* gr = getgrgid( MASS_ROOT_GID);
	struct group* gr = getgrnam( massRootGroupName );
//	printf( "gr_name=%s gr_gid=%d\n",
//		gr->gr_name, gr->gr_gid );

	int i = 0;
	char** mem = gr->gr_mem;
	while( mem[i] ) {
//		printf( "%s ?\n",mem[i] );
		if( strcmp( mem[i], userName ) == 0 ) {
//			printf( "%s is MassRoot!\n",userName );
			return true;
		}
		i++;
	}
//	printf( "%s is User!\n",userName );
	return false;
}

void setAccess( const char* fileName, bool toMassRoot ) {
	if(!fileName) return;
	gid_t gid;
//	if( toMassRoot ) gid = (gid_t)MASS_ROOT_GID;
//	else gid = (gid_t)MASS_GID;
	if( toMassRoot ) gid = getGID( massRootGroupName );
	else gid = getGID( massUserGroupName );

    chown( fileName, (uid_t) -1, gid );
	chmod( fileName, S_IRUSR | S_IWUSR |
			S_IRGRP | S_IWGRP | S_IROTH );
}

/*
int main( int argc, char ** argv ) {
	getMassAccess();
}
*/
